#include "osl/container/bitXmask.h"
#include <iostream>
#include <cppunit/TestCase.h>
#include <cppunit/extensions/HelperMacros.h>

using namespace osl;

class bitXmaskTest : public CppUnit::TestFixture 
{
  CPPUNIT_TEST_SUITE( bitXmaskTest );
  CPPUNIT_TEST_SUITE_END();
 public:
  void testShow();
};

CPPUNIT_TEST_SUITE_REGISTRATION(bitXmaskTest);

void bitXmaskTest::testShow(){
  Square p0=Square(8,3);
  BitXmask xMask;
  xMask.clearAll();
  xMask.set(p0.x());
  std::cerr << p0 << ',' << xMask ;
}

